Learn R Programming

HVT (version 24.9.1)

edaPlots: plots for data analysis

Description

This is the main function that provides exploratory data analysis plots

Usage

edaPlots(df, time_column, output_type = NULL, n_cols = 2)

Value

Five objects which include time series plots, data distribution plots, box plots, correlation plot and a descriptive statistics table.

Arguments

df

Dataframe. A data frame object.

time_column

Character. The name of the time column in the data frame. Can be given only when the data is time series

output_type

Character. The name of the output to be displayed. Options are 'summary', 'histogram', 'boxplot', 'timeseries' & 'correlation'. Default value is NULL.

n_cols

Numeric. A value to indicate how many columns to be included in the output. Default value is 2.

Author

Vishwavani <vishwavani@mu-sigma.com>

Examples

Run this code
dataset <- data.frame(date = as.numeric(time(EuStockMarkets)),
                      DAX = EuStockMarkets[, "DAX"],
                      SMI = EuStockMarkets[, "SMI"],
                      CAC = EuStockMarkets[, "CAC"],
                      FTSE = EuStockMarkets[, "FTSE"])
edaPlots(dataset, time_column = 'date', output_type = 'timeseries', n_cols = 5)
edaPlots(dataset, time_column = 'date', output_type = 'histogram', n_cols = 5)

Run the code above in your browser using DataLab