Learn R Programming

HVT (version 24.9.1)

getCellId: Cell ID

Description

Function to generate cell ID based on 1D sammons projection

Usage

getCellId(hvt.results, seed = 123)

Value

Object containing Cell.ID mappings for the given hvt.results list.

Arguments

hvt.results

List. A list of hvt.results obtained from the trainHVT function.

seed

Numeric. Random Seed

Author

Shubhra Prakash <shubhra.prakash@mu-sigma.com>

Details

To generate cell id for the multivariate data, the data is being projected from n-dimensions to 1-dimension and the cell id is being assigned by ordering these values and finding the corresponding indexes. The output Cell id gets appended to the HVT model.