Function to generate cell ID based on 1D sammons projection
getCellId(hvt.results, seed = 123)Object containing Cell.ID mappings for the given hvt.results list.
List. A list of hvt.results obtained from the trainHVT function.
Numeric. Random Seed
Shubhra Prakash <shubhra.prakash@mu-sigma.com>
To generate cell id for the multivariate data, the data is being projected from n-dimensions to 1-dimension and the cell id is being assigned by ordering these values and finding the corresponding indexes. The output Cell id gets appended to the HVT model.